@@ -12,7 +12,8 @@ from SharedData.SharedDataAWSS3 import S3SyncDownloadMetadata,S3Upload
 
 class Metadata():
     
-    def __init__(self, name, mode='rw', user='master'):
+    def __init__(self, name, mode='rw', user='master',\
+        sync_frequency_days=None, debug=None):
         
         if Logger.log is None:
             Logger('Metadata')
