@@ -147,17 +147,24 @@ class KinesisLogStreamConsumer():
         if self.stream and 'StreamDescription' in self.stream:
             self.stream = self.stream['StreamDescription']
             i=0    
+            
             for i in range(len(self.stream['Shards'])):        
+                readfromstart = True
                 shardid = self.stream['Shards'][i]['ShardId']
                 if not self.dflogs.empty and (shardid in self.dflogs['shardid'].values):            
+                    readfromstart = False
                     seqnum = self.dflogs[self.dflogs['shardid']==shardid].iloc[-1]['sequence_number']
-                    shard_iterator = self.client.get_shard_iterator(
-                        StreamName=self.stream['StreamName'],
-                        ShardId=self.stream['Shards'][i]['ShardId'],
-                        ShardIteratorType='AFTER_SEQUENCE_NUMBER',
-                        StartingSequenceNumber=seqnum
-                        )
-                else:
+                    try:
+                        shard_iterator = self.client.get_shard_iterator(
+                            StreamName=self.stream['StreamName'],
+                            ShardId=self.stream['Shards'][i]['ShardId'],
+                            ShardIteratorType='AFTER_SEQUENCE_NUMBER',
+                            StartingSequenceNumber=seqnum
+                            )
+                    except:
+                        readfromstart=True
+                
+                if readfromstart:
                     shard_iterator = self.client.get_shard_iterator(
                         StreamName=self.stream['StreamName'],
                         ShardId=self.stream['Shards'][i]['ShardId'],                
@@ -193,7 +200,8 @@ class KinesisLogStreamConsumer():
                             if not logfilepath.parents[0].is_dir():
                                 os.makedirs(logfilepath.parents[0])
                             with open(logfilepath,'a+',encoding = 'utf-8') as f:
-                                f.write(line.replace('\n',' ').replace('\r',' ')+'\n')  
+                                f.write(line.replace('\n',' ').replace('\r',' ')+'\n')
+                                f.flush()
                         except Exception as e:
                             print('Invalid record:'+str(rec))
                             print('Invalid record error:'+str(e))
