@@ -38,9 +38,7 @@ class SharedDataFeeder():
                 self.data[period] = SharedDataPeriod(self, period)
                 ustartdate = self.dataset.set_index('period')['startDate'].unique()
                 for startdate in ustartdate:
-                    self.data[period].getContinousTimeIndex(startdate)
-            
-        
+                    self.data[period].getContinousTimeIndex(startdate)    
     
     def __setitem__(self, period, value):
         self.data[period] = value
@@ -91,16 +89,18 @@ class SharedDataFeeder():
 
         if tags is None:
             # create a thread pool
-            with ThreadPoolExecutor(len(self[period].tags)) as exe:
-                futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in self[period].tags.keys()]
-                # collect data
-                data = [future.result() for future in futures]
+            if len(self[period].tags)>0:
+                with ThreadPoolExecutor(len(self[period].tags)) as exe:
+                    futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in self[period].tags.keys()]
+                    # collect data
+                    data = [future.result() for future in futures]
         else:            
-            # create a thread pool
-            with ThreadPoolExecutor(len(tags)) as exe:            
-                futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in tags]
-                # collect data
-                data = [future.result() for future in futures]
+            if len(tags)>0:
+                # create a thread pool
+                with ThreadPoolExecutor(len(tags)) as exe:            
+                    futures = [exe.submit(self.save_tag, period, tag, startDate) for tag in tags]
+                    # collect data
+                    data = [future.result() for future in futures]
 
     def save_tag(self, period, tag, startDate=None):
         if startDate is None:
