@@ -33,7 +33,7 @@ try:
         ' subscription database:%s' % (DATABASE))
 
     consumer = KinesisStreamConsumer(streamname)
-    shdata = SharedData(DATABASE,sync_frequency_days=0)
+    shdata = SharedData(DATABASE)
 
     Logger.log.info('SharedData real time'+\
         ' subscription database:%s STARTED!' % (DATABASE))
